from distutils.core import setup
setup(
  name = 'xy_facedetect',
  packages = ['xy_facedetect'],
  version = '2.0.0',
  description = 'Get The Face Detect',
  long_description='Get The Face Detect',
  author = 'KingHS',
  author_email = '382771946@qq.com',
  keywords = ['pip3', 'python3','python','face detect','face','detect'],
  license='MIT',
  install_requires=['opencv-python']
)
